Installation
************

.. code-block:: shell

    pip install pysynthetic

Or simply from the tarball or source code if you are not using *pip*.

.. code-block:: shell

    python setup.py install

